﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.Web.UI.GridControls;


public partial class _Default : System.Web.UI.Page 
{
    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);
        this.WebHierarchicalDataGrid1.RowAdding += new RowAddingHandler(WebHierarchicalDataGrid1_RowAdding);
        this.WebHierarchicalDataGrid1.RowsDeleting += new RowDeletingHandler(WebHierarchicalDataGrid1_RowDeleting);
        this.WebHierarchicalDataGrid1.RowUpdating += new RowUpdatingHandler(WebHierarchicalDataGrid1_RowUpdating);
    }

    protected void Page_Load(object sender, EventArgs e)
    {

        if (Session["ActorsAndMoviesDS"] != null)
        {
            this.WebHierarchicalDataGrid1.DataSource = Session["ActorsAndMoviesDS"] as DataSet;
        }
        else
        {
            this.WebHierarchicalDataGrid1.DataSource = CreateDataSet();
        }

        this.WebHierarchicalDataGrid1.DataBind();
    }

    #region Row Updating
    protected void WebHierarchicalDataGrid1_RowUpdating(object sender, RowUpdatingEventArgs e)
    {
        ContainerGrid containerGrid = (ContainerGrid)sender;

        if (containerGrid.Level == 0)
        {
            UpdateActor(Convert.ToInt32(e.Values["ActorID"]), Convert.ToString(e.Values["Name"]));
        }
        if (containerGrid.Level == 1)
        {
            UpdateMovie(Convert.ToInt32(e.Values["MovieID"]), Convert.ToString(e.Values["Title"]), Convert.ToInt32(e.Values["Year"]));
        }
    }

    private void UpdateActor(int actorId, string name)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            DataRow actorRow = ds.Tables["Actors"].Rows.Find(actorId);
            if (actorRow != null)
            {
                actorRow["Name"] = name;
            }
        }
    }

    private void UpdateMovie(int movieId, string title, int year)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            DataRow movieRow = ds.Tables["Movies"].Rows.Find(movieId);
            if (movieRow != null)
            {
                movieRow["Title"] = title;
                movieRow["Year"] = year;
            }
        }
    }
    #endregion

    #region Row Deleteing

    protected void WebHierarchicalDataGrid1_RowDeleting(object sender, RowDeletingEventArgs e)
    {
        ContainerGrid containerGrid = (ContainerGrid)sender;

        if (containerGrid.Level == 0)
        {
            DeleteActor(Convert.ToInt32(e.Row.DataKey[0]));
        }
        if (containerGrid.Level == 1)
        {
            DeleteMovie(Convert.ToInt32(e.Row.DataKey[0]));
        }
    }

    private void DeleteActor(int actorId)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            DataRow actorRow = ds.Tables["Actors"].Rows.Find(actorId);
            if (actorRow != null)
            {
                actorRow.Delete();
            }
        }
    }

    private void DeleteMovie(int movieId)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            DataRow movieRow = ds.Tables["Movies"].Rows.Find(movieId);
            if (movieRow != null)
            {
                movieRow.Delete();
            }
        }
    }

    #endregion

    #region Row Adding

    protected void WebHierarchicalDataGrid1_RowAdding(object sender, RowAddingEventArgs e)
    {
        ContainerGrid containerGrid = (ContainerGrid)sender;

        if (containerGrid.Level == 0)
        {
            AddActor(Convert.ToString(e.Values["Name"]));
        }
        if (containerGrid.Level == 1)
        {
            AddMovie(containerGrid.ParentRow.Index, Convert.ToString(e.Values["Title"]), Convert.ToInt32(e.Values["Year"]));
        }
    }

    private void AddActor(string name)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            ds.Tables["Actors"].Rows.Add(CreateActorRow(ds.Tables["Actors"], name));
        }
    }

    private void AddMovie(int actorID, string title, int year)
    {
        if (HttpContext.Current.Session["ActorsAndMoviesDS"] != null)
        {
            DataSet ds = Session["ActorsAndMoviesDS"] as DataSet;
            ds.Tables["Movies"].Rows.Add(CreateMoviesRow(ds.Tables["Movies"], actorID, title, year));
        }
    }

    #endregion

    #region DataSource

    private DataSet CreateDataSet()
    {
        DataSet ds = new DataSet();

        ds.Tables.Add(Actors());
        ds.Tables.Add(Movies());

        DataRelation dR = new DataRelation("id", ds.Tables["Actors"].Columns["ActorID"], ds.Tables["Movies"].Columns["ActorID"]);
        ds.Relations.Add(dR);


        Session["ActorsAndMoviesDS"] = ds;
        return ds;
    }

    private DataTable Actors()
    {
        DataTable actors = new DataTable("Actors");
        DataColumn primaryKey = new DataColumn("ActorID");
        primaryKey.DataType = System.Type.GetType("System.Int32");
        primaryKey.AutoIncrement = true;
        actors.Columns.Add(primaryKey);
        actors.PrimaryKey = new DataColumn[] { primaryKey };
        actors.Columns.Add("Name", System.Type.GetType("System.String"));
        FillActors(actors);
        return actors;
    }

    private DataTable Movies()
    {
        DataTable movies = new DataTable("Movies");
        DataColumn primaryKey = new DataColumn("MovieID");
        primaryKey.DataType = System.Type.GetType("System.Int32");
        primaryKey.AutoIncrement = true;
        movies.Columns.Add(primaryKey);
        movies.Columns.Add("ActorID", System.Type.GetType("System.Int32"));
        movies.Columns.Add("Title", System.Type.GetType("System.String"));
        movies.Columns.Add("Year", System.Type.GetType("System.Int32"));
        movies.PrimaryKey = new DataColumn[] { primaryKey };
        FillMovies(movies);
        return movies;
    }

    private void FillActors(DataTable actors)
    {
        actors.Rows.Add(CreateActorRow(actors, "Kevin Spacey"));
        actors.Rows.Add(CreateActorRow(actors, "Edward Norton"));
        actors.Rows.Add(CreateActorRow(actors, "Adam Sandler"));
        actors.Rows.Add(CreateActorRow(actors, "Will Smith"));
    }

    private DataRow CreateActorRow(DataTable actors, string name)
    {
        DataRow actorRow = actors.NewRow();
        actorRow["Name"] = name;
        return actorRow;
    }

    private void FillMovies(DataTable movies)
    {
        movies.Rows.Add(CreateMoviesRow(movies, 0, "K-PAX", 2001));
        movies.Rows.Add(CreateMoviesRow(movies, 0, "L.A. Confidential", 1997));
        movies.Rows.Add(CreateMoviesRow(movies, 0, "The Usual Suspects", 1995));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "25th Hour", 2002));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "Fight Club", 1999));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "American History X", 1998));

    }

    private DataRow CreateMoviesRow(DataTable movies, int actorId, string title, int year)
    {
        DataRow movieRow = movies.NewRow();
        movieRow["ActorID"] = actorId;
        movieRow["Title"] = title;
        movieRow["Year"] = year;
        return movieRow;
    }

    #endregion
}
